Color Me
===============================

.. image:: https://img.shields.io/pypi/v/color_me.svg
   :target: https://pypi.python.org/pypi/color_me

.. image:: https://img.shields.io/pypi/pyversions/color_me.svg
   :target: https://pypi.python.org/pypi/color_me

.. image:: https://img.shields.io/travis/kalekundert/color_me.svg
   :target: https://travis-ci.org/kalekundert/color_me

.. image:: https://img.shields.io/coveralls/kalekundert/color_me.svg
   :target: https://coveralls.io/github/kalekundert/color_me?branch=master
